aboutsummaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorrub <rub@piwigo.org>2007-09-19 05:26:58 +0000
committerrub <rub@piwigo.org>2007-09-19 05:26:58 +0000
commite74e4567495b5ef46866ba7d4040ff49c9ccfee7 (patch)
treee12f58c9d8b5c870cc4601c62b5254270d1c67bf /include
parent131cf74ba44c35ac82cb949bf33794c8f579105c (diff)
Resolved 0000748: Name configuration of all the tables
Resolved 0000750: Check anomalies after upgrade (Feature proposition) git-svn-id: http://piwigo.org/svn/trunk@2096 68402e56-0260-453c-a942-63ccdbb3a9ee
Diffstat (limited to 'include')
-rw-r--r--include/config_default.inc.php39
-rw-r--r--include/constants.php63
2 files changed, 68 insertions, 34 deletions
diff --git a/include/constants.php b/include/constants.php
index 8b211f631..308be5940 100644
--- a/include/constants.php
+++ b/include/constants.php
@@ -45,35 +45,36 @@ define('ACCESS_ADMINISTRATOR', 3);
define('ACCESS_WEBMASTER', 4);
// Table names
-define('CATEGORIES_TABLE', $prefixeTable.'categories');
-define('COMMENTS_TABLE', $prefixeTable.'comments');
-define('CONFIG_TABLE', $prefixeTable.'config');
-define('FAVORITES_TABLE', $prefixeTable.'favorites');
-define('GROUP_ACCESS_TABLE', $prefixeTable.'group_access');
-define('GROUPS_TABLE', $prefixeTable.'groups');
-define('HISTORY_TABLE', $prefixeTable.'history');
-define('HISTORY_SUMMARY_TABLE', $prefixeTable.'history_summary');
-define('IMAGE_CATEGORY_TABLE', $prefixeTable.'image_category');
-define('IMAGES_TABLE', $prefixeTable.'images');
-define('SESSIONS_TABLE', $prefixeTable.'sessions');
-define('SITES_TABLE', $prefixeTable.'sites');
-define('USER_ACCESS_TABLE', $prefixeTable.'user_access');
-define('USER_GROUP_TABLE', $prefixeTable.'user_group');
-define('USERS_TABLE', $conf['users_table']);
-define('USER_INFOS_TABLE', $prefixeTable.'user_infos');
-define('USER_FEED_TABLE', $prefixeTable.'user_feed');
-define('WAITING_TABLE', $prefixeTable.'waiting');
-define('IMAGE_METADATA_TABLE', $prefixeTable.'image_metadata');
-define('RATE_TABLE', $prefixeTable.'rate');
-define('USER_CACHE_TABLE', $prefixeTable.'user_cache');
-define('USER_CACHE_CATEGORIES_TABLE', $prefixeTable.'user_cache_categories');
-define('CADDIE_TABLE', $prefixeTable.'caddie');
-define('UPGRADE_TABLE', $prefixeTable.'upgrade');
-define('SEARCH_TABLE', $prefixeTable.'search');
-define('USER_MAIL_NOTIFICATION_TABLE', $prefixeTable.'user_mail_notification');
-define('TAGS_TABLE', $prefixeTable.'tags');
-define('IMAGE_TAG_TABLE', $prefixeTable.'image_tag');
-define('PLUGINS_TABLE', $prefixeTable.'plugins');
-define('WEB_SERVICES_ACCESS_TABLE', $prefixeTable.'ws_access');
-define('OLD_PERMALINKS_TABLE', $prefixeTable.'old_permalinks');
+define('CATEGORIES_TABLE', $conf['tables']['categories_table']);
+define('COMMENTS_TABLE', $conf['tables']['comments_table']);
+define('CONFIG_TABLE', $conf['tables']['config_table']);
+define('FAVORITES_TABLE', $conf['tables']['favorites_table']);
+define('GROUP_ACCESS_TABLE', $conf['tables']['group_access_table']);
+define('GROUPS_TABLE', $conf['tables']['groups_table']);
+define('HISTORY_TABLE', $conf['tables']['history_table']);
+define('HISTORY_SUMMARY_TABLE', $conf['tables']['history_summary_table']);
+define('IMAGE_CATEGORY_TABLE', $conf['tables']['image_category_table']);
+define('IMAGES_TABLE', $conf['tables']['images_table']);
+define('SESSIONS_TABLE', $conf['tables']['sessions_table']);
+define('SITES_TABLE', $conf['tables']['sites_table']);
+define('USER_ACCESS_TABLE', $conf['tables']['user_access_table']);
+define('USER_GROUP_TABLE', $conf['tables']['user_group_table']);
+define('USERS_TABLE', $conf['tables']['users_table']);
+define('USER_INFOS_TABLE', $conf['tables']['user_infos_table']);
+define('USER_FEED_TABLE', $conf['tables']['user_feed_table']);
+define('WAITING_TABLE', $conf['tables']['waiting_table']);
+define('IMAGE_METADATA_TABLE', $conf['tables']['image_metadata_table']);
+define('RATE_TABLE', $conf['tables']['rate_table']);
+define('USER_CACHE_TABLE', $conf['tables']['user_cache_table']);
+define('USER_CACHE_CATEGORIES_TABLE', $conf['tables']['user_cache_categories_table']);
+define('CADDIE_TABLE', $conf['tables']['caddie_table']);
+define('UPGRADE_TABLE', $conf['tables']['upgrade_table']);
+define('SEARCH_TABLE', $conf['tables']['search_table']);
+define('USER_MAIL_NOTIFICATION_TABLE', $conf['tables']['user_mail_notification_table']);
+define('TAGS_TABLE', $conf['tables']['tags_table']);
+define('IMAGE_TAG_TABLE', $conf['tables']['image_tag_table']);
+define('PLUGINS_TABLE', $conf['tables']['plugins_table']);
+define('WEB_SERVICES_ACCESS_TABLE', $conf['tables']['web_services_access_table']);
+define('OLD_PERMALINKS_TABLE', $conf['tables']['old_permalinks_table']);
+
?>
diff --git a/include/config_default.inc.php b/include/config_default.inc.php
index 64ade722b..f14a9a0d2 100644
--- a/include/config_default.inc.php
+++ b/include/config_default.inc.php
@@ -430,8 +430,10 @@ $conf['die_on_sql_error'] = true;
// users table ?
$conf['apache_authentication'] = false;
// users_table: which table is the reference for users? Can be a different
// table than PhpWebGallery table
//
// If you decide to use another table than the default one, you need to
// prepare your database by deleting some datas :
@@ -449,7 +451,38 @@ $conf['apache_authentication'] = false;
//
// All informations contained in these tables and column are related to
// phpwebgallery_users table.
-$conf['users_table'] = $prefixeTable.'users';
+
+$conf['tables']['categories_table'] = $prefixeTable.'categories';
+$conf['tables']['comments_table'] = $prefixeTable.'comments';
+$conf['tables']['config_table'] = $prefixeTable.'config';
+$conf['tables']['favorites_table'] = $prefixeTable.'favorites';
+$conf['tables']['group_access_table'] = $prefixeTable.'group_access';
+$conf['tables']['groups_table'] = $prefixeTable.'groups';
+$conf['tables']['history_table'] = $prefixeTable.'history';
+$conf['tables']['history_summary_table'] = $prefixeTable.'history_summary';
+$conf['tables']['image_category_table'] = $prefixeTable.'image_category';
+$conf['tables']['images_table'] = $prefixeTable.'images';
+$conf['tables']['sessions_table'] = $prefixeTable.'sessions';
+$conf['tables']['sites_table'] = $prefixeTable.'sites';
+$conf['tables']['user_access_table'] = $prefixeTable.'user_access';
+$conf['tables']['user_group_table'] = $prefixeTable.'user_group';
+$conf['tables']['users_table'] = $prefixeTable.'users';
+$conf['tables']['user_infos_table'] = $prefixeTable.'user_infos';
+$conf['tables']['user_feed_table'] = $prefixeTable.'user_feed';
+$conf['tables']['waiting_table'] = $prefixeTable.'waiting';
+$conf['tables']['image_metadata_table'] = $prefixeTable.'image_metadata';
+$conf['tables']['rate_table'] = $prefixeTable.'rate';
+$conf['tables']['user_cache_table'] = $prefixeTable.'user_cache';
+$conf['tables']['user_cache_categories_table'] = $prefixeTable.'user_cache_categories';
+$conf['tables']['caddie_table'] = $prefixeTable.'caddie';
+$conf['tables']['upgrade_table'] = $prefixeTable.'upgrade';
+$conf['tables']['search_table'] = $prefixeTable.'search';
+$conf['tables']['user_mail_notification_table'] = $prefixeTable.'user_mail_notification';
+$conf['tables']['tags_table'] = $prefixeTable.'tags';
+$conf['tables']['image_tag_table'] = $prefixeTable.'image_tag';
+$conf['tables']['plugins_table'] = $prefixeTable.'plugins';
+$conf['tables']['web_services_access_table'] = $prefixeTable.'ws_access';
+$conf['tables']['old_permalinks_table'] = $prefixeTable.'old_permalinks';
// user_fields : mapping between generic field names and table specific
// field names. For example, in PWG, the mail address is names
@@ -430,8 +430,10 @@ $conf['die_on_sql_error'] = true;
// users table ?
$conf['apache_authentication'] = false;
-// users_table: which table is the reference for users? Can be a different
-// table than PhpWebGallery table
+// With $conf['tables'] you can use external tables
+// For example with $conf['tables']['users_table']:
+// which table is the reference for users? Can be a different
+// table than PhpWebGallery table
//
// If you decide to use another table than the default one, you need to